searchData={"items":[{"type":"module","title":"ProdopsEx.Artifact","doc":"Handles artifact operations for the ProdOps API such as retrieving artifacts\nfor a given project, creating artifacts, refining artifacts, and deleting artifacts.\n\nArtifacts are any generated content, i.e. user stories, blog posts, code\nsnippets, etc. They are organized by `artifact_slug`s, which define what type\nof content they are. Most artifact operations require specifying the\n`artifact_slug`.\n\nThey are generated by passing input into a prompt template. Inputs come from\nup to three places:\n - user inputs: you can specify what values these have when creating Artifacts\n - document queries: semantically similar parts of documents are automatically\n   found within a collection of documents, and inserted into the prompt template\n   prior to generation, known as Retrieval-Augmented Generation (RAG)\n- document attachments: an entire document, such as something uploaded by you,\n  is inserted into the prompt template prior to generation","ref":"ProdopsEx.Artifact.html"},{"type":"function","title":"ProdopsEx.Artifact.create/2","doc":"Creates an artifact by submitting a request with the required parameters.","ref":"ProdopsEx.Artifact.html#create/2"},{"type":"function","title":"Parameters - ProdopsEx.Artifact.create/2","doc":"- `params`: The parameters for the artifact request.\n- `config` (optional): a configuration map used to override default config values","ref":"ProdopsEx.Artifact.html#create/2-parameters"},{"type":"function","title":"Examples - ProdopsEx.Artifact.create/2","doc":"iex> ProdopsEx.Artifact.create(%{\n    ...>   prompt_template_id: 2,\n    ...>   artifact_slug: \"story\",\n    ...>   project_id: 1,\n    ...>   inputs: [\n    ...>     %{name: \"Context\", value: \"this is a test\"}\n    ...>   ],\n    ...>   fire_and_forget: true\n    ...> })\n    {:ok, %{\"artifact_id\" => 123, \"status\" => \"created\"}}","ref":"ProdopsEx.Artifact.html#create/2-examples"},{"type":"function","title":"ProdopsEx.Artifact.delete/3","doc":"Deletes an artifact by its ID.","ref":"ProdopsEx.Artifact.html#delete/3"},{"type":"function","title":"Parameters - ProdopsEx.Artifact.delete/3","doc":"- `artifact_id`: the ID of the artifact\n- `artifact_slug`: the type of the artifact to be deleted\n- `config` (optional): a configuration map used to override default config values","ref":"ProdopsEx.Artifact.html#delete/3-parameters"},{"type":"function","title":"Example - ProdopsEx.Artifact.delete/3","doc":"iex> ProdopsEx.Artifact.delete(1, \"story\")\n    {:ok,\n      %{status: \"ok\", response: %{\"message\" => \"Artifact deleted successfully.\"}}}","ref":"ProdopsEx.Artifact.html#delete/3-example"},{"type":"function","title":"ProdopsEx.Artifact.get/3","doc":"Retrieves an artifact by its ID.","ref":"ProdopsEx.Artifact.html#get/3"},{"type":"function","title":"Parameters - ProdopsEx.Artifact.get/3","doc":"- `artifact_id`: the ID of the artifact\n- `artifact_slug`: the slug which defines the type of artifact that will be returned\n- `config` (optional): a configuration map used to override default config values","ref":"ProdopsEx.Artifact.html#get/3-parameters"},{"type":"function","title":"Example - ProdopsEx.Artifact.get/3","doc":"iex> ProdopsEx.Artifact.get(1, \"story\")\n    {:ok,\n     %{\n       status: \"ok\",\n       response: %{\n         \"artifact\" => %{\n           \"chat_history\" => [\n             %{\n               \"content\" => \"some user prompt content\",\n               \"role\" => \"user\"\n             },\n             %{\n               \"content\" => \"some assistant response content\",\n               \"role\" => \"assistant\"\n             }\n           ],\n           \"id\" => 123,\n           \"manually_edited\" => false,\n           \"name\" => \"Some Name\",\n           \"notes\" => nil,\n           \"share_token\" => nil\n         }\n       }\n     }}","ref":"ProdopsEx.Artifact.html#get/3-example"},{"type":"function","title":"ProdopsEx.Artifact.list_project_artifacts/3","doc":"Retrieves artifacts of one type based on the `artifact_slug` for a given project.","ref":"ProdopsEx.Artifact.html#list_project_artifacts/3"},{"type":"function","title":"Parameters - ProdopsEx.Artifact.list_project_artifacts/3","doc":"- `project_id`: the ID of the project\n- `artifact_slug`: the slug which defines the type of artifacts that will be returned\n- `config` (optional): a configuration map used to override default config values","ref":"ProdopsEx.Artifact.html#list_project_artifacts/3-parameters"},{"type":"function","title":"Example - ProdopsEx.Artifact.list_project_artifacts/3","doc":"iex> ProdopsEx.Artifact.list_project_artifacts(1, \"story\")\n    {:ok,\n      %{\n        status: \"ok\",\n        response: %{\n          \"artifacts\" => [\n            %{\n              \"chat_history\" => [\n                %{\n                  \"content\" => \"You are going to be a product manager and write a BDD-style user story...\",\n                  \"role\" => \"user\"\n                },\n                %{\n                  \"content\" => \"","ref":"ProdopsEx.Artifact.html#list_project_artifacts/3-example"},{"type":"function","title":"Background ...\", - ProdopsEx.Artifact.list_project_artifacts/3","doc":"\"role\" => \"assistant\"\n                }\n              ],\n              \"content\" => \"","ref":"ProdopsEx.Artifact.html#list_project_artifacts/3-background"},{"type":"function","title":"Background ...\", - ProdopsEx.Artifact.list_project_artifacts/3","doc":"\"id\" => 1,\n              \"manually_edited\" => false,\n              \"name\" => \"Artifact Name\",\n              \"notes\" => nil,\n              \"share_token\" => nil\n            }\n          ]\n        }\n      }}","ref":"ProdopsEx.Artifact.html#list_project_artifacts/3-background"},{"type":"function","title":"Returns - ProdopsEx.Artifact.list_project_artifacts/3","doc":"The function returns a list of artifacts for the specified project which\nmatch the artifact slug.","ref":"ProdopsEx.Artifact.html#list_project_artifacts/3-returns"},{"type":"function","title":"ProdopsEx.Artifact.refine_artifact/2","doc":"Refines an artifact by submitting a request with the required parameters.","ref":"ProdopsEx.Artifact.html#refine_artifact/2"},{"type":"function","title":"Parameters - ProdopsEx.Artifact.refine_artifact/2","doc":"- `params`: The parameters for the artifact request.\n- `config`: The configuration map containing the API key and optionally the URL.","ref":"ProdopsEx.Artifact.html#refine_artifact/2-parameters"},{"type":"function","title":"Example - ProdopsEx.Artifact.refine_artifact/2","doc":"iex> ProdopsEx.Artifact.refine_artifact(%{\n    ...>   artifact_id: 1,\n    ...>   artifact_slug: \"story\",\n    ...>   refine_prompt: \"Refine this story\"\n    ...> })","ref":"ProdopsEx.Artifact.html#refine_artifact/2-example"},{"type":"function","title":"ProdopsEx.Artifact.stream_create_artifact/2","doc":"Creates an artifact by submitting a request with the required parameters.","ref":"ProdopsEx.Artifact.html#stream_create_artifact/2"},{"type":"function","title":"Parameters - ProdopsEx.Artifact.stream_create_artifact/2","doc":"- `params`: The parameters for the artifact creation request.\n- `config`: The configuration map containing the API key and endpoint URL.","ref":"ProdopsEx.Artifact.html#stream_create_artifact/2-parameters"},{"type":"function","title":"Example - ProdopsEx.Artifact.stream_create_artifact/2","doc":"iex> ProdopsEx.Artifact.stream_create_artifact(%{\n    ...>   prompt_template_id: 2,\n    ...>   project_id: 1,\n    ...>   artifact_slug: \"story\",\n    ...>   inputs: [\n    ...>     %{name: \"Context\", value: \"this is a test\"}\n    ...>   ]\n    ...> })","ref":"ProdopsEx.Artifact.html#stream_create_artifact/2-example"},{"type":"function","title":"ProdopsEx.Artifact.stream_refine_artifact/2","doc":"Refines an artifact by submitting a request with the required parameters.","ref":"ProdopsEx.Artifact.html#stream_refine_artifact/2"},{"type":"function","title":"Parameters - ProdopsEx.Artifact.stream_refine_artifact/2","doc":"- `params`: The parameters for the artifact request.\n- `config`: The configuration map containing the API key and endpoint URL.","ref":"ProdopsEx.Artifact.html#stream_refine_artifact/2-parameters"},{"type":"function","title":"Example - ProdopsEx.Artifact.stream_refine_artifact/2","doc":"iex> ProdopsEx.Artifact.stream_refine_artifact(%{artifact_slug: \"story\", artifact_id: 1, refine_prompt: \"some prompt\"})","ref":"ProdopsEx.Artifact.html#stream_refine_artifact/2-example"},{"type":"module","title":"ProdopsEx.ArtifactType","doc":"Handles artifact type operations for the ProdOps API.\n\nThese represent types of outputs. They may be things like user stories, code\nsnippets, blog posts, or anything else that has been defined within the\nProdOps UI. They are used to classify generated Artifacts into groups.","ref":"ProdopsEx.ArtifactType.html"},{"type":"function","title":"ProdopsEx.ArtifactType.list/1","doc":"Returns a list of all artifact types for a given team","ref":"ProdopsEx.ArtifactType.html#list/1"},{"type":"function","title":"Examples - ProdopsEx.ArtifactType.list/1","doc":"iex> ProdopsEx.ArtifactType.list()\n    {:ok,\n      %{\n        status: \"ok\",\n        response: %{\n          \"artifact_types\" => [\n            %{\n              \"description\" => \"This is a story\",\n              \"name\" => \"Story\",\n              \"slug\" => \"story\"\n            },\n            ...\n          ]\n        }\n      }\n    }","ref":"ProdopsEx.ArtifactType.html#list/1-examples"},{"type":"module","title":"ProdopsEx.DataCenter","doc":"Handles data center operations for the ProdOps API.\n\nThe Data Center is used for:\n - uploading documents\n - managing collections of documents\n - connecting external Data Sources (GitHub, Jira, Notion, etc.)\n\nNot all of these items are currently supported by the ProdOps API, so there\nis additional functionality in the UI not yet available in this SDK.","ref":"ProdopsEx.DataCenter.html"},{"type":"function","title":"ProdopsEx.DataCenter.upload_document/2","doc":"Uploads a document to the ProdOps data center.","ref":"ProdopsEx.DataCenter.html#upload_document/2"},{"type":"function","title":"Parameters - ProdopsEx.DataCenter.upload_document/2","doc":"- `path_to_file`: the full path to the file that will be uploaded\n- `config` (optional): a configuration map used to override default config values","ref":"ProdopsEx.DataCenter.html#upload_document/2-parameters"},{"type":"function","title":"Examples - ProdopsEx.DataCenter.upload_document/2","doc":"iex> ProdopsEx.DataCenter.upload_document(\"/path/to/file.txt\")\n    {:ok, %{status: \"ok\", response: %{\"id\" => 4}}}","ref":"ProdopsEx.DataCenter.html#upload_document/2-examples"},{"type":"module","title":"ProdopsEx.Project","doc":"Handles project operations for the ProdOps API.\n\nA Project is used for organization, and likely represents some real-world\nproject, such as development of an application. Some resources can be\nProject-scoped. A Team may have multiple Projects.","ref":"ProdopsEx.Project.html"},{"type":"function","title":"ProdopsEx.Project.list/1","doc":"Returns a list of all projects for a given team","ref":"ProdopsEx.Project.html#list/1"},{"type":"function","title":"Parameters - ProdopsEx.Project.list/1","doc":"- `config` (optional): a configuration map used to override default config values","ref":"ProdopsEx.Project.html#list/1-parameters"},{"type":"function","title":"Examples - ProdopsEx.Project.list/1","doc":"iex> ProdopsEx.Project.list()\n    {:ok,\n      %{\n        status: \"ok\",\n        response: %{\n          \"projects\" => [\n            %{\n              \"id\" => 1,\n              \"name\" => \"Project Name\",\n              \"overview\" => \"Project Overview\"\n            },\n            %{\n              \"id\" => 2,\n              \"name\" => \"Second Project\",\n              \"overview\" => \"Second Project Overview\"\n            }\n          ]\n        }\n      }\n    }","ref":"ProdopsEx.Project.html#list/1-examples"},{"type":"module","title":"ProdopsEx.PromptTemplate","doc":"Handles prompt template operations for the ProdOps API.\n\nPrompt Templates are the building blocks used for generating Artifacts.\n\nThey are a combination of hard-coded information and variables which represent\ndata that can be inserted. They are the basic building block for setting up\nrepeatable workflows to generate Artifacts.\n\nThey may look something like this:\n\n```txt\nYou are a helpful assistant. A user has asked a question about company\npolicies, which you must answer. This is their question:\n\n{custom.Question}\n\nUse this information to answer the question:\n\n{query.Company Policies}\n```\n\nThe value `{custom.Question}` can be explicitly passed into the template\nwhen generating a new Artifact.\n\nThe value `{query.Company Policies}` will automatically find relevant\ninformation by checking the value of an explicit input such as\n`{custom.Question}`, and can search through all Documents or a Collection of\nDocuments. In this example, it might search a Collection of employee manuals,\nplaybooks, etc., and will calculate the most semantically similar values\nbetween their sections and the user's question, which is the value input into\n`{custom.Question}`. It will then return the relevant segments and insert them\ninto the prompt prior to generation. This technique is known as\nRetrieval-Augmented Generation.\n\nFor more information, see the [ProdOps.AI Prompts help page](https://help.prodops.ai/docs/category/prompts).","ref":"ProdopsEx.PromptTemplate.html"},{"type":"function","title":"ProdopsEx.PromptTemplate.list/2","doc":"Retrieves prompt templates for a given artifact type.","ref":"ProdopsEx.PromptTemplate.html#list/2"},{"type":"function","title":"Parameters - ProdopsEx.PromptTemplate.list/2","doc":"- `artifact_slug`: the type of prompt templates to return from the request\n- `config` (optional): a configuration map used to override default config values","ref":"ProdopsEx.PromptTemplate.html#list/2-parameters"},{"type":"function","title":"Example - ProdopsEx.PromptTemplate.list/2","doc":"iex> ProdopsEx.PromptTemplate.list(\"questions\")\n\t{:ok,\n\t %{\n\t\t status: \"ok\",\n\t\t response: %{\n\t\t\t \"prompt_templates\" => [\n\t\t\t\t %{\n\t\t\t\t\t \"content\" => \"Answer this: {custom.Question} Use these docs: {query.Documents}\",\n\t\t\t\t\t \"custom_variables\" => [\n\t\t\t\t\t\t %{\n\t\t\t\t\t\t\t \"question\" => \"Question\",\n\t\t\t\t\t\t\t \"id\" => \"fc4cbbe7-8f90-4c39-a8e6-582d37884f14\",\n\t\t\t\t\t\t\t \"name\" => \"Question\"\n\t\t\t\t\t\t }\n\t\t\t\t\t ],\n\t\t\t\t\t \"description\" => \"Answers a question using document queries\",\n\t\t\t\t\t \"document_queries\" => [\n\t\t\t\t\t\t %{\n\t\t\t\t\t\t\t \"collection_id\" => nil,\n\t\t\t\t\t\t\t \"collection_ids\" => ~c\"s\",\n\t\t\t\t\t\t\t \"count\" => 3,\n\t\t\t\t\t\t\t \"id\" => \"6c69b859-8c40-41c9-b8f9-8bb1bdf369a1\",\n\t\t\t\t\t\t\t \"min_score\" => 0.75,\n\t\t\t\t\t\t\t \"name\" => \"Documents\",\n\t\t\t\t\t\t\t \"query\" => \"{custom.Question}\",\n\t\t\t\t\t\t\t \"type\" => nil\n\t\t\t\t\t\t }\n\t\t\t\t\t ],\n\t\t\t\t\t \"id\" => 1,\n\t\t\t\t\t \"name\" => \"Question Answering\"\n\t\t\t\t }\n\t\t\t ]\n\t\t }\n\t }}","ref":"ProdopsEx.PromptTemplate.html#list/2-example"},{"type":"function","title":"Returns - ProdopsEx.PromptTemplate.list/2","doc":"The function returns a list of prompt templates for the specified artifact type.","ref":"ProdopsEx.PromptTemplate.html#list/2-returns"},{"type":"module","title":"ProdopsEx.Validate","doc":"Handles validation operations for the ProdOps API.","ref":"ProdopsEx.Validate.html"},{"type":"function","title":"ProdopsEx.Validate.validate_api_key/1","doc":"Validates the provided API key and returns team information.","ref":"ProdopsEx.Validate.html#validate_api_key/1"},{"type":"function","title":"Parameters - ProdopsEx.Validate.validate_api_key/1","doc":"- `config` (optional): a configuration map used to override default config values","ref":"ProdopsEx.Validate.html#validate_api_key/1-parameters"},{"type":"function","title":"Example - ProdopsEx.Validate.validate_api_key/1","doc":"iex> ProdopsEx.Validate.validate_api_key()\n    {:ok, %{status: \"ok\", response: %{\"team_id\" => 1, \"team_name\" => \"ProdOps\"}}}","ref":"ProdopsEx.Validate.html#validate_api_key/1-example"},{"type":"extras","title":"ProdopsEx: The Prodops Elixir SDK","doc":"# ProdopsEx: The Prodops Elixir SDK\n\nProdopsEx allows for access to the powerful Prodops API via Elixir. \nThis SDK allows for the creation and refinement of artifacts (content) within a ProdOps team.\nOther features include data center document, uploads, project management and more.","ref":"readme.html"},{"type":"extras","title":"Motivation - ProdopsEx: The Prodops Elixir SDK","doc":"To provide a simple way to interact with the Prodops API from within Elixir.","ref":"readme.html#motivation"},{"type":"extras","title":"Build Status - ProdopsEx: The Prodops Elixir SDK","doc":"![tests](https://github.com/revelrylabs/prodops_ex/actions/workflows/test.yml/badge.svg)","ref":"readme.html#build-status"},{"type":"extras","title":"Key Features - ProdopsEx: The Prodops Elixir SDK","doc":"- Create and manage artifacts (content) within a ProdOps team.\n- Refine existing artifacts.\n- Upload documents to ProdOps data center.\n- Stream the creation and refining of artifacts.","ref":"readme.html#key-features"},{"type":"extras","title":"Installation - ProdopsEx: The Prodops Elixir SDK","doc":"Add ProdopsEx to your mix.exs:\n\n```elixir\ndef deps do\n  [\n    {:prodops_ex, \"~> 0.1.0\"}\n  ]\nend\n```\n\nFetch dependencies:\n\n```\nmix deps.get\n```\n\n[Sign up for a ProdOps account](https://app.prodops.ai) if you don't already\nhave one, then go to Settings -> Team -> Manage Team Details to get your API\nkey. If you don't see Manage Team Details, you will need to ask an administrator \non your team for access. More into can be found on our [help site](https://help.prodops.ai/docs/api/get-your-api-token).\n\nPut the API key somewhere in your application configuration, such as\n`dev.secret.exs`:\n\n```\nconfig :prodops_ex, api_key: \"YOUR_API_KEY\"\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - ProdopsEx: The Prodops Elixir SDK","doc":"Create a new artifact in ProdOps\n\n```elixir\nparams = %{\n      prompt_template_id: 2,\n      artifact_slug: \"story\",\n      inputs: [\n        %{name: \"Context\", value: \"this is a test\"}\n      ],\n      fire_and_forget: true\n    }\n\nartifact = ProdopsEx.Artifact.create(params)\n```\n\nThis will create a new artifact of the given artifact type for the given team matching the api token placed in the config. \n\n```elixir\n{:ok, %{\"artifact_id\" => 123, \"status\" => \"created\"}}\n```","ref":"readme.html#usage"},{"type":"extras","title":"ProdOps.AI Definitions - ProdopsEx: The Prodops Elixir SDK","doc":"- Team: Synonymous with Company or Organization.  Teams can have one or many Users.  Teams can have details that define who they are, what they do, and what their culture represents.  Q: Are there constraints or limiters on Teams (e.g. domain) \n- Users: A member of a team.  A person who uses ProdOps.AI to create something.  Users are defined by email address and constrained by that email address to one Team.  \n- Project: A software development (or other) project, product, or idea, generally defined with a goal.  A ProdOps project could have a start and a finish, like a typical project (Build a wordpress marketing site for NOLA PD; Update the Revelry website with new creative and branding).  As well, a ProdOps project could be an ongoing effort, such as a product (Platform, Peerbot, Apple Music).  At its most basic, a ProdOps project is the subject that will drive the types of content that will be generated.  \n- Artifact Types: Every piece of content generated in ProdOps has a type, which determines the purpose, format, and types of prompt used in generating the thing. Users define their own prompt template types based on their needs.\n- Prompt templates / Prompt / Template: A re-usable template that contains both dynamic and static data. When the user is generating an artifact, this is what they will interact with, and that collaboration is what is sent to the LLM. Prompt templates are grouped by the type of artifact selected.","ref":"readme.html#prodops-ai-definitions"},{"type":"extras","title":"Contributing and Development - ProdopsEx: The Prodops Elixir SDK","doc":"Bug reports and pull requests are welcome on GitHub at https://github.com/revelrylabs/prodops_ex. Check out the [contributing guidelines](CONTRIBUTING.md) for more info.\n\nEveryone is welcome to participate in the project. We expect contributors to adhere to the [Contributor Covenant Code of Conduct](CODE_OF_CONDUCT.md).","ref":"readme.html#contributing-and-development"},{"type":"extras","title":"Releases - ProdopsEx: The Prodops Elixir SDK","doc":"See [RELEASES.md](RELEASES.md) for details about the release process.","ref":"readme.html#releases"},{"type":"extras","title":"Documentation - ProdopsEx: The Prodops Elixir SDK","doc":"Documentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Docs can be found at  .\n\nProdops.AI documentation can be found on the [help site](https://help.prodops.ai).","ref":"readme.html#documentation"},{"type":"extras","title":"License - ProdopsEx: The Prodops Elixir SDK","doc":"ProdopsEx is released under the MIT License. See the [LICENSE](LICENSE) file for details.","ref":"readme.html#license"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2024 Revelry Labs, LLC\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"},{"type":"extras","title":"Contributing and Development","doc":"# Contributing and Development","ref":"contributing.html"},{"type":"extras","title":"API Key - Contributing and Development","doc":"You'll need a [ProdOps API key](https://help.prodops.ai/docs/api/get-your-api-token)\nto get started. Copy `config/config.example-secret.exs` to\n`config/config.secret.exs` and put your API key into that file.","ref":"contributing.html#api-key"},{"type":"extras","title":"Development Setup - Contributing and Development","doc":"1. Make sure you have Elixir 1.12+ installed\n1. Clone the repo\n1. Run `mix deps.get`\n1. Run `mix test`\n\nYou can run the same checks that are in the CI pipeline, which is run via GitHub Actions:\n\n```\n./presubmit.sh\n```\n\nFor convenience we recommend using this as a pre-push hook:\n\n```\ncp presubmit.sh .git/hooks/pre-push\n```\n\nYou can run the library via the `iex` shell to run functions through it, e.g.:\n\n```\niex -S mix\niex()> ProdopsEx.Artifact.get(123, \"story\")\n```","ref":"contributing.html#development-setup"},{"type":"extras","title":"Submitting Changes - Contributing and Development","doc":"1. Find or open an Issue related to the changes you're making\n1. Fork the project\n1. Create a new topic branch to contain your feature, change, or fix.\n1. Make sure all the checks are still passing: the CI system runs these checks automatically\n1. Implement your feature, change, or fix. Make sure to write tests, update and/or add documentation.\n1. Push your topic branch up to your fork.\n1. Open a Pull Request with a clear title and description, and mention the related Issue(s)","ref":"contributing.html#submitting-changes"},{"type":"extras","title":"Releasing a new version","doc":"# Releasing a new version","ref":"releases.html"},{"type":"extras","title":"Preparation - Releasing a new version","doc":"- [ ] Update the package version in `mix.exs`\n- [ ] Update the package version badge and installation instructions in `README.md`","ref":"releases.html#preparation"},{"type":"extras","title":"Release Process - Releasing a new version","doc":"- [ ] Make sure all changes in the `Preparation` section are in `main`\n- [ ] In GitHub, create, and publish, a new release with appropriate notes, and version matching the package version `mix.exs`\n- [ ] The github actions workflow should automatically publish the package and docs to hex","ref":"releases.html#release-process"},{"type":"extras","title":"Contributor Covenant Code of Conduct","doc":"# Contributor Covenant Code of Conduct","ref":"code_of_conduct.html"},{"type":"extras","title":"Our Pledge - Contributor Covenant Code of Conduct","doc":"In the interest of fostering an open and welcoming environment, we as\ncontributors and maintainers pledge to making participation in our project and\nour community a harassment-free experience for everyone, regardless of age, body\nsize, disability, ethnicity, gender identity and expression, level of experience,\nnationality, personal appearance, race, religion, or sexual identity and\norientation.","ref":"code_of_conduct.html#our-pledge"},{"type":"extras","title":"Our Standards - Contributor Covenant Code of Conduct","doc":"Examples of behavior that contributes to creating a positive environment\ninclude:\n\n* Using welcoming and inclusive language\n* Being respectful of differing viewpoints and experiences\n* Gracefully accepting constructive criticism\n* Focusing on what is best for the community\n* Showing empathy towards other community members\n\nExamples of unacceptable behavior by participants include:\n\n* The use of sexualized language or imagery and unwelcome sexual attention or\nadvances\n* Trolling, insulting/derogatory comments, and personal or political attacks\n* Public or private harassment\n* Publishing others' private information, such as a physical or electronic\n  address, without explicit permission\n* Other conduct which could reasonably be considered inappropriate in a\n  professional setting","ref":"code_of_conduct.html#our-standards"},{"type":"extras","title":"Our Responsibilities - Contributor Covenant Code of Conduct","doc":"Project maintainers are responsible for clarifying the standards of acceptable\nbehavior and are expected to take appropriate and fair corrective action in\nresponse to any instances of unacceptable behavior.\n\nProject maintainers have the right and responsibility to remove, edit, or\nreject comments, commits, code, wiki edits, issues, and other contributions\nthat are not aligned to this Code of Conduct, or to ban temporarily or\npermanently any contributor for other behaviors that they deem inappropriate,\nthreatening, offensive, or harmful.","ref":"code_of_conduct.html#our-responsibilities"},{"type":"extras","title":"Scope - Contributor Covenant Code of Conduct","doc":"This Code of Conduct applies both within project spaces and in public spaces\nwhen an individual is representing the project or its community. Examples of\nrepresenting a project or community include using an official project e-mail\naddress, posting via an official social media account, or acting as an appointed\nrepresentative at an online or offline event. Representation of a project may be\nfurther defined and clarified by project maintainers.","ref":"code_of_conduct.html#scope"},{"type":"extras","title":"Enforcement - Contributor Covenant Code of Conduct","doc":"Instances of abusive, harassing, or otherwise unacceptable behavior may be\nreported by contacting the project team at support@revelry.co. All\ncomplaints will be reviewed and investigated and will result in a response that\nis deemed necessary and appropriate to the circumstances. The project team is\nobligated to maintain confidentiality with regard to the reporter of an incident.\nFurther details of specific enforcement policies may be posted separately.\n\nProject maintainers who do not follow or enforce the Code of Conduct in good\nfaith may face temporary or permanent repercussions as determined by other\nmembers of the project's leadership.","ref":"code_of_conduct.html#enforcement"},{"type":"extras","title":"Attribution - Contributor Covenant Code of Conduct","doc":"This Code of Conduct is adapted from the [Contributor Covenant][homepage], version 1.4,\navailable at [http://contributor-covenant.org/version/1/4][version]\n\n[homepage]: http://contributor-covenant.org\n[version]: http://contributor-covenant.org/version/1/4/","ref":"code_of_conduct.html#attribution"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}